# unipress
This is a library developed by Institute of High Pressure Physics of Polish Academy of Sciences.

# Description

## Approximations

This submodule contains approximations of functions related to physical phenomena.

Functions:

- `tau_scoul1`, `tau_scoul2`: approximations of the Shockley-Read-Hall recombination capture time accounting for the attraction of the minority carrier by the Coulomb force. They depend on capture length to Coulomb length ratio, Coulomb length to screening distance ratio and original SRH parameter for the considered semiconductor material.



